@@ -14,7 +14,6 @@
 #define __SETTINGS_H
 
 #include "PageViewBase.h"
-#include "History.h"
 #include "EnumMap.h"
 #include <QObject>
 #include <QFont>
@@ -27,28 +26,29 @@ namespace QComicBook
 {
 	using namespace Utility;
 
-        class ComicMainWindow;
+	class ComicMainWindow;
         
 	class ComicBookSettings: public QObject
 	{
 		Q_OBJECT
 
 		signals:
-                        void displaySettingsChanged(const QString &option);
+			void displaySettingsChanged(const QString &option);
 
 		public:
 			void load();
 
-                        bool embedPageNumbers() const;
+			bool embedPageNumbers() const;
 			bool smallCursor() const;
 			bool twoPagesMode() const;
 			bool japaneseMode() const;
 			bool continuousScrolling() const;
+			ViewType viewType() const;
 			bool scrollbarsVisible() const;
 			Size pageSize() const;
 			bool smoothScaling() const;
 			QString lastDir() const;
-			const History& recentlyOpened() const;
+			const QStringList& recentlyOpened() const;
 			QColor background() const;
 			int cacheSize() const;
 			bool cacheAutoAdjust() const;
@@ -66,17 +66,19 @@ namespace QComicBook
 			void restoreDockLayout(ComicMainWindow *w) const;
 			bool showSplash() const;
 			QString tmpDir() const;
+			bool showDonationDialog() const;
 
-                        void embedPageNumbers(bool f);
+			void embedPageNumbers(bool f);
 			void smallCursor(bool f);
 			void twoPagesMode(bool f);
 			void japaneseMode(bool f);
 			void continuousScrolling(bool f);
+			void viewType(ViewType t);
 			void scrollbarsVisible(bool f);
 			void pageSize(Size s);
 			void smoothScaling(bool s);
 			void lastDir(const QString &d);
-			void recentlyOpened(const History &hist);
+			void recentlyOpened(const QStringList &hist);
 			void background(const QColor &color);
 			void cacheSize(int s);
 			void cacheAutoAdjust(bool f);
@@ -94,6 +96,7 @@ namespace QComicBook
 			void saveGeometry(ComicMainWindow *w);
 			void showSplash(bool f);
 			void tmpDir(const QString &dir);
+			bool showDonationDialog(bool f);
 
 			static ComicBookSettings& instance();
 
@@ -106,7 +109,7 @@ namespace QComicBook
 
 		private:
 			QSettings *m_cfg;
-                        bool m_embedpagenumbers;
+			bool m_embedpagenumbers;
 			bool m_smallcursor;
 			bool m_twopages;
 			bool m_twopagesstep;
@@ -118,10 +121,11 @@ namespace QComicBook
 			bool m_fscrhidestatus;
 			bool m_fscrhidetoolbar;
 			Size m_pagesize;
+			ViewType m_viewtype;
 			bool m_smoothscaling;
 			QString m_lastdir;
 			QColor m_bgcolor;
-			History m_recent;
+			QStringList m_recent;
 			int m_cachesize;
 			int m_thumbsage;
 			bool m_cacheadjust;
@@ -131,6 +135,7 @@ namespace QComicBook
 			bool m_statusbar;
 			bool m_intbrowser;
 			bool m_showsplash;
+			bool m_donationdlg;
 			QString m_tmpdir;
 			QFont m_font;
 
@@ -139,11 +144,12 @@ namespace QComicBook
 			bool m_dirsok; //is above dirs are ok
 
 			static const EnumMap<Size> size2string[];
+			static const EnumMap<ViewType> viewtype2string[];
 
-                        ComicBookSettings();
-                        ComicBookSettings(const ComicBookSettings &);
-                        ComicBookSettings operator =(const ComicBookSettings &);
-                        virtual ~ComicBookSettings();
+			ComicBookSettings();
+			ComicBookSettings(const ComicBookSettings &);
+			ComicBookSettings operator =(const ComicBookSettings &);
+			virtual ~ComicBookSettings();
 
 
 	};
